.dsl-panel {
	height: calc(100% - 18px - 1em);
	width: calc(50% - 5px);
	float: left;
	background-color: white;
	border: 1px solid gray;
	overflow-x: hidden;
	overflow-y: auto;

	border-radius: 5px 5px 5px 5px;
	-moz-border-radius: 5px 5px 5px 5px;
	-webkit-border-radius: 5px 5px 5px 5px;
}

.dsl-panel:hover {
	-webkit-box-shadow: 0px 0px 6px 2px rgba(138,138,138,1);
	-moz-box-shadow: 0px 0px 6px 2px rgba(138,138,138,1);
	box-shadow: 0px 0px 6px 2px rgba(138,138,138,1);
}

.dsl-panel.left-panel {
	margin-right: 6px;
}

.dsl-panel::-webkit-scrollbar-track
{
	-webkit-box-shadow: inset 0 0 6px rgba(0,0,0,0.3);
	border-radius: 6px;
	background-color: #F5F5F5;
}

.dsl-panel::-webkit-scrollbar
{
	width: 6px;
	background-color: #F5F5F5;
}

.dsl-panel::-webkit-scrollbar-thumb
{
	border-radius: 6px;
	-webkit-box-shadow: inset 0 0 6px rgba(0,0,0,.3);
	background-color: #C5C5C5;
}

.dsl-filter {
	width: calc(50% - 6px);
	float: left;
	margin-bottom: 3px;
	border: 1px solid rgba(1,1,1,0);
}

.dsl-filter.left-panel {
	margin-right: 6px;
}

.dsl-filter-input {
	font-size: 1em;
	font-style: Italic;
	font-weight: bolder;
	color: lightgray;
	width: calc(100% - 5px);
	border: 1px solid gray;
	font-family: Calibri;
	padding: 3px 0px 3px 5px;

	border-radius: 5px 5px 5px 5px;
	-moz-border-radius: 5px 5px 5px 5px;
	-webkit-border-radius: 5px 5px 5px 5px;
}

.dsl-panel-item {
	font-size: 1em;
	width: calc(100% - 16px);
	margin: 3px;
	padding: 5px;
	font-family: Calibri;
	background-color: #FFE99D;
	cursor: pointer;

	border-radius: 3px 3px 3px 3px;
	-moz-border-radius: 3px 3px 3px 3px;
	-webkit-border-radius: 3px 3px 3px 3px;
}

.dsl-panel-item:hover {
	background-color: #FFC679;
}

.dsl-panel-item-null {
	font-size: 1em;
	width: calc(100% - 22px);
	margin: 3px;
	padding: 5px;
	font-family: Calibri;
	background-color: white;
	cursor: pointer;
	border: 3px dashed lightgray;
	display: none;

	border-radius: 3px 3px 3px 3px;
	-moz-border-radius: 3px 3px 3px 3px;
	-webkit-border-radius: 3px 3px 3px 3px;
}

